@@ -22,12 +22,38 @@
 
 import unittest
 
-from factory.declarations import OrderedDeclaration, Sequence
+from factory.declarations import deepgetattr, OrderedDeclaration, Sequence
 
 class OrderedDeclarationTestCase(unittest.TestCase):
     def test_errors(self):
         decl = OrderedDeclaration()
         self.assertRaises(NotImplementedError, decl.evaluate, None, {})
 
+
+class DigTestCase(unittest.TestCase):
+    class MyObj(object):
+        def __init__(self, n):
+            self.n = n
+
+    def test_chaining(self):
+        obj = self.MyObj(1)
+        obj.a = self.MyObj(2)
+        obj.a.b = self.MyObj(3)
+        obj.a.b.c = self.MyObj(4)
+
+        self.assertEqual(2, deepgetattr(obj, 'a').n)
+        self.assertRaises(AttributeError, deepgetattr, obj, 'b')
+        self.assertEqual(2, deepgetattr(obj, 'a.n'))
+        self.assertEqual(3, deepgetattr(obj, 'a.c', 3))
+        self.assertRaises(AttributeError, deepgetattr, obj, 'a.c.n')
+        self.assertRaises(AttributeError, deepgetattr, obj, 'a.d')
+        self.assertEqual(3, deepgetattr(obj, 'a.b').n)
+        self.assertEqual(3, deepgetattr(obj, 'a.b.n'))
+        self.assertEqual(4, deepgetattr(obj, 'a.b.c').n)
+        self.assertEqual(4, deepgetattr(obj, 'a.b.c.n'))
+        self.assertEqual(42, deepgetattr(obj, 'a.b.c.n.x', 42))
+
+
+
 if __name__ == '__main__':
     unittest.main()
